@@ -239,7 +239,23 @@ def aggParentDSTrio(results):
             return results
         pfid = row['pfid']
         rdict.setdefault(pfid, []).append([row['r'], row['l']])
-    return rdict
+    return [rdict]
+
+def aggBlockTrio(results):
+    """
+    performs listBlockTrio API aggregation
+
+    :param: results: list JSON records
+    :type: list
+    :return: aggregated list of JSON records
+    """
+    rdict = {}
+    for row in results:
+        if 'cfid' not in row:
+            return results
+        cfid = row['cfid']
+        rdict.setdefault(cfid, []).append([row['r'], row['l']])
+    return [rdict]
 
 def slicedIterator(sourceList, sliceSize):
     """
@@ -760,7 +776,7 @@ class DbsApi(object):
         requiredParameters = {'forced': ['block_name']}
         checkInputParameter(method="listBlockTrio", parameters=list(kwargs.keys()), validParameters=validParameters,
                             requiredParameters=requiredParameters)
-        return self.__callServer("blockTrio", params=kwargs, callmethod='GET')
+        return self.__callServer("blockTrio", params=kwargs, callmethod='GET', aggFunc=aggBlockTrio)
 
     def listFileParentsByLumi(self, **kwargs):
         """
